#!/bin/sh

[ "$_GET[\"action\"]" = "del_filter" ] && _GET["filter"]="" && _GET["filtertype"]="" 
listcards() {
  case "$_GET["filtertype"]" in
    any)
       grep -il "$_GET[\"filter\"]" ${_DATA}/vcard/*vcf
      ;;
    name)
       egrep -xil "(FN|NICKNAME|N)(;.+)*:.*$_GET[\"filter\"].*" ${_DATA}/vcard/*vcf
      ;;
    street)
       egrep -xil "(ADR)(;.+)*:([^;]*;){2}$_GET[\"filter\"].*" ${_DATA}/vcard/*vcf
      ;;
    zip)
       egrep -xil "(ADR)(;.+)*:([^;]*;){5}$_GET[\"filter\"].*" ${_DATA}/vcard/*vcf
      ;;
    telephone)
       egrep -xil "(TEL)(;.+)*:.*$_GET[\"filter\"].*" ${_DATA}/vcard/*vcf
      ;;
    birth)
       egrep -xil "(BDAY)(;.+)*:$_GET[\"filter\"].*" ${_DATA}/vcard/*vcf
      ;;
    course)
      ;;
    *) ls -1 ${_DATA}/vcard/*vcf
      ;;
  esac
}

vcf_parse() {
  tr -d '\n' <"$1" |sed -r 's:\r ::g;s:\r:\n:g' \
  | sed -rn '
    s:^PHOTO:001 PHOTO:p;
    s:^X-MS-CARDPICTURE:001 PHOTO:p;
    s:^LOGO:002 LOGO:p;
    s:^FN:003 FN:p;
    s:^NICKNAME:005 NICKNAME:p;
    s:^N:004 N:p
    s:^SOUND:006 SOUND:p;
    s:^GENDER:007 GENDER:p;
    s:^X-GENDER:007 GENDER:p;
    s:^KIND:008 KIND:p;
    s:^TITLE:009 TITLE:p;
    s:^ROLE:010 ROLE:p;
    s:^ORG:011 ORG:p;
    s:^MEMBER:012 MEMBER:p;
    s:^CATEGORIES:013 CATEGORIES:p;
    s:^ANNIVERSARY:014 ANNIVERSARY:p;
    s:^X-ANNIVERSARY:014 ANNIVERSARY:p;
    s:^X-EVOLUTION-ANNIVERSARY:014 ANNIVERSARY:p;
    s:^X-KADDRESSBOOK-X-Anniversary:014 ANNIVERSARY:p;
    s:^BDAY:015 BDAY:p;
    s:^EMAIL:016 EMAIL:p;
    s:^TEL:017 TEL:p;
    s:^IMPP:018 IMPP:p;
    s:^X-AIM(;[^"\:]+|;"[^"]+")*\:(.*)$:018 IMPP\1\:aim\:\2:p;
    s:^X-ICQ(;[^"\:]+|;"[^"]+")*\:(.*)$:018 IMPP\1\:aim\:\2:p;
    s:^X-GOOGLE-TALK(;[^"\:]+|;"[^"]+")*\:(.*)$:018 IMPP\1\:xmpp\:\2:p;
    s:^X-JABBER(;[^"\:]+|;"[^"]+")*\:(.*)$:018 IMPP\1\:xmpp\:\2:p;
    s:^X-MSN(;[^"\:]+|;"[^"]+")*\:(.*)$:018 IMPP\1\:msn\:\2:p;
    s:^X-YAHOO(;[^"\:]+|;"[^"]+")*\:(.*)$:018 IMPP\1\:ymsgr\:\2:p;
    s:^X-SIP(;[^"\:]+|;"[^"]+")*\:(sip\:)?(.*)$:018 IMPP\1\:sip\:\3:p;
    s:^ADR:019 ADR:p;
    s:^LABEL(;[^"\:]+|;"[^"]+")*\:(.*)$:019 ADR;LABEL="\2"\1\::p;
    s:^URL:021 URL:p;
    s:^X-EVOLUTION-BLOG-URL:021 URL:p;
    s:^LANG:022 LANG:p;
    s:^NOTE:023 NOTE:p;

    s:^RELATED:025 RELATED:p;
    s:^AGENT:025 RELATED\;TYPE=agent:p;
    s:^X-ASSISTANT:025 RELATED\;TYPE=assistant;VALUE=text:p;
    s:^X-EVOLUTION-ASSISTANT:025 RELATED\;TYPE=assistant;VALUE=text:p;
    s:^X-KADDRESSBOOK-X-AssistantsName:025 RELATED\;TYPE=assistant;VALUE=text:p;
    s:^X-MANAGER:025 RELATED\;TYPE=manager;VALUE=text:p;
    s:^X-EVOLUTION-MANAGER:025 RELATED\;TYPE=manager;VALUE=text:p;
    s:^X-KADDRESSBOOK-X-ManagersName:025 RELATED\;TYPE=manager;VALUE=text:p;
    s:^X-SPOUSE:025 RELATED\;TYPE=spouse;VALUE=text:p;
    s:^X-EVOLUTION-SPOUSE:025 RELATED\;TYPE=spouse;VALUE=text:p;
    s:^X-KADDRESSBOOK-X-SpouseName:025 RELATED\;TYPE=spouse;VALUE=text:p;

    s:^BEGIN.*$:000 &:p;
    s:^CALADRURI.*$::;
    s:^CALURI.*$::;
    s:^CLASS.*$::;
    s:^CLIENTPIDMAP.*$::;
    s:^END.*$:100 &:p;
    s:^FBURL.*$::;
    s:^GEO.*$::;
    s:^MAILER.*$::;
    s:^NAME.*$::;
    s:^PRODID.*$::;
    s:^PROFILE.*$::;
    s:^REV.*$::;
    s:^SORT-STRING.*$::;
    s:^SOURCE.*$::;
    s:^TZ.*$::;
    s:^UID.*$::;
    s:^VERSION.*$:000 VERSION\:4.0:p;
    s:^XML.*$::;

    s:^([A-Z].*)$:024 \1:p;
    ' \
  | sort |while read -r line; do
    case "$line" in
      00[012]*)
	echo -E "$line"
	;;
      003*)
	fn=$(echo -E "$line" |sed -r 's:^[0-9]{3} ([^;\:]+)(;[^"\:]+|;"[^"]+")*\:(.*)$:\3:g' |tr -d '\r')
	;;
      004*)
	n=$(echo -E "$line" \
	  |sed -rn 's:^([0-9]{3} )([^;\:]+)(;[^"\:]+|;"[^"]+")*\:([^;]*)(\;[^;]*)(\;[^;]*)?(\;[^;]*)?(\;[^;]*)?$:\7 \5 \6 \4 \8:gp' \
	  |sed -r 's:,: :;s:\;: :g;s: +: :g' \
	  |tr -d '\r'
	)
	echo -E "$line"
	;;
      005*)
	nick=$(echo -E "$line" |sed -r 's:^[0-9]{3} ([^;\:]+)(;[^"\:]+|;"[^"]+")*\:(.*)$:\3:g' |tr -d '\r')
	echo -E "$line"
	;;
      *)
        [ -n "$n" ] && fn="$n"
	#[ -n "$fn" -a -n "$nick" ] && fn="$fn aka. $nick"
	[ -n "$fn" ] && echo -E "003 FN:$fn" \
	 	      || echo -E "003 FN:$nick"
	echo -E "$line"
	cat
	;;
    esac
  done |tr -d '\r' \
  | sed -r 's:^[0-9]{3} ([^;\:]+)(;[^"\:]+|;"[^"]+")*\:(.*)$:key="\1"\nvalue="\3"\ntag=\2:g' \
  | while read -r line; do
    case "$line" in
      key=*) echo -E "$line"
	;;
      value=*) echo -E "$line"
	;;
      tag=*) ot=''
	     echo -E "$line" \
	     | sed -r 's:^tag=::;s:\;([A-Z+_-]+="[^"]+"|[A-Z+_-]+=[^\;]+):\n\1:g;' \
	     | sed -r 's:([A-Z+_-]+)="?(.*)"?:tag\[\1\]="\2":g' \
	     | sed -r '/^ *$/d' \
	     | sort |while read -r tag; do
	       nt="$(echo -E "$tag" |sed -r 's:^tag\[([A-Z+_-]+)\]="(.*)"$:\1:')"
	       nv="$(echo -E "$tag" |sed -r 's:^tag\[([A-Z+_-]+)\]="(.*)"$:\2:')"
	       [ "$nt" = "$ot" ] && vl="$nv,$vl" || vl="$nv"
	       echo -E "tag[$nt]=\"$vl\""
	       ot="$nt"
	     done
	;;
    esac
  done
}

case "$1" in
  title)
    echo "Teilnehmende"
  ;;
  css)
    . ${_EXEC}/templates/attendees.css.sh
  ;;
  body)
    . ${_EXEC}/templates/attendees.html.sh
  ;;
esac
  
